﻿Type=Class
Version=4.2
ModulesStructureVersion=1
B4J=true
@EndOfDesignText@
'Class module
Sub Class_Globals
	Private ws As WebSocket 'ignore
	' will hold our page information
	Public page As ABMPage
	' page theme
	Private theme As ABMTheme
	' to access the constants
	Private ABM As ABMaterial 'ignore	
	' name of the page, must be the same as the class name (case sensitive!)
	Public Name As String = "IconsPage"
	' name of the app, same as in ABMApplication
	Public AppName As String = "demo"
	
	' your own variables
	Dim myToastId As Int
End Sub

'Initializes the object. You can add parameters to this method if needed.
Public Sub Initialize
	' build the local structure IMPORTANT!
	BuildPage
End Sub

Private Sub WebSocket_Connected (WebSocket1 As WebSocket)
	Log("Connected")
	ws = WebSocket1	
	If ABMShared.NeedsAuthorization Then
		If ws.Session.GetAttribute2("IsAuthorized", "") = "" Then
			ABMShared.NavigateToPage(ws, "../")
			Return
		End If
	End If
	' connect our page with the websocket	
	page.SetWebSocket(ws)
	' Prepare the page IMPORTANT!
	page.Prepare	
End Sub

Private Sub WebSocket_Disconnected
	Log("Disconnected")
End Sub

Sub Page_ParseEvent(Params As Map) 
	Dim eventName As String = Params.Get("eventname")
	Dim eventParams() As String = Regex.Split(",",Params.Get("eventparams"))
	If SubExists(Me, eventName) Then
		Params.Remove("eventname")
		Params.Remove("eventparams")
		Select Case Params.Size
			Case 0
				CallSub(Me, eventName)
			Case 1
				CallSub2(Me, eventName, Params.Get(eventParams(0)))					
			Case 2
				If Params.get(eventParams(0)) = "abmistable" Then
					Dim PassedTables As List = ABM.ProcessTablesFromTargetName(Params.get(eventParams(1)))
					CallSub2(Me, eventName, PassedTables)
				Else
					CallSub3(Me, eventName, Params.Get(eventParams(0)), Params.Get(eventParams(1)))
				End If
			Case Else
				' cannot be called diretly, to many param
				CallSub2(Me, eventName, Params)				
		End Select
	End If
End Sub

public Sub BuildTheme()
	' start with the base theme defined in ABMShared
	theme.Initialize("pagetheme")
	theme.AddABMTheme(ABMShared.MyTheme)
	
	' add additional themes specific for this page
	' cell theme
	theme.AddCellTheme("cellLB")
	theme.Cell("cellLB").BackColor = ABM.COLOR_LIGHTBLUE
	theme.Cell("cellLB").BackColorIntensity = ABM.INTENSITY_DARKEN4
	theme.Cell("cellLB").BorderColor = ABM.COLOR_WHITE
	theme.Cell("cellLB").BorderWidth = 1
	
	' footer label theme
	theme.AddLabelTheme("white")
	theme.Label("white").ForeColor = ABM.COLOR_WHITE
	theme.Label("white").Align = ABM.TEXTALIGN_CENTER
	theme.Label("white").IconColor = ABM.COLOR_WHITE
	
	theme.AddDividerTheme("white")
	theme.Divider("white").ForeColor = ABM.COLOR_WHITE
			
End Sub

public Sub BuildPage()
	' initialize the theme
	BuildTheme
	
	' initialize this page using our theme
	page.InitializeWithTheme(Name, "/ws/" & AppName & "/" & Name, False, theme)
	page.ShowLoader=True
	page.PageTitle = "Material Icons"
	page.PageDescription = "List of the material icons"	
	page.PageHTMLName = "abmaterial-material-icons.html"
	page.PageKeywords = "ABMaterial, material design, B4X, B4J, SEO, framework, search engine optimization"
	page.PageSiteMapPriority = "0.50"
	page.PageSiteMapFrequency = ABM.SITEMAP_FREQ_MONTHLY
	page.UseGoogleAnalytics(ABMShared.TrackingID, Null) ' IMPORTANT Change this to your own TrackingID !!!!!!!
		
	ABMShared.BuildNavigationBar(page, "Icons", "../images/logo.png", "", "Icons", "")
		
	' create the page grid
	page.AddRows(1,True, "").AddCells12(1,"")
	page.AddRows(1,True, "").AddCellsOS(4,0,0,0,12,6,3,"cellLB")
	page.BuildGrid 'IMPORTANT once you loaded the complete grid AND before you start adding components
	
	' add a header label
	page.Cell(1,1).AddComponent(ABMShared.BuildHeader(page,"hdr1", "Introduction"))
	' add paragraph	
	page.Cell(1,1).AddComponent(ABMShared.BuildParagraph(page,"par1","Some components, like the label, have an icon property. You can use the Google Icons. ") )
		
	' add a header label
	page.Cell(1,1).AddComponent(ABMShared.BuildHeader(page,"hdr2", "Icon names you can use"))
	' add paragraph	
	page.Cell(1,1).AddComponent(ABMShared.BuildParagraph(page,"par4","Here is a list of all the icon names you can use.") )
	' add paragraph	
	
	Dim Icons As List = LoadIcons
	
	Dim imgCounter As Int = 0
	Dim j As Int
	Do While imgCounter < Icons.Size
		Dim lblicon As ABMLabel
		lblicon.Initialize(page, "icon" & imgCounter & "icon", "", ABM.SIZE_PARAGRAPH, False, "white")
		lblicon.IconName = Icons.get(imgCounter)
		lblicon.IconSize = ABM.ICONSIZE_MEDIUM
		page.Cell(2, j+1).AddComponent(lblicon)
	
		Dim lbliconName As ABMLabel
		lbliconName.Initialize(page, "icon" & imgCounter & "lbl", Icons.get(imgCounter), ABM.SIZE_PARAGRAPH, False, "white")
		lbliconName.Truncate = True
		page.Cell(2, j+1).AddComponent(lbliconName)
			
		Dim div As ABMDivider
		div.Initialize(page, "icon" & imgCounter & "div" , "white")
		page.Cell(2, j+1).AddComponent(div)
			
		imgCounter = imgCounter + 1	
		j = j + 1
		If j = 4 Then
			j = 0	
		End If
	Loop
		
	ABMShared.BuildFooter(page)
End Sub

' clicked on the navigation bar
Sub Page_NavigationbarClicked(Action As String, Value As String)
	page.SaveNavigationBarPosition	
	If Action = "Icons" Then Return
	If Action = "Contact" Then	
		myToastId = myToastId + 1	
		page.ShowToast("toast" & myToastId, "toastred", "Hello to you too!", 5000)
		Return
	End If
	If Action = "LogOff" Then
		ABMShared.LogOff(page)
		Return
	End If
	ABMShared.NavigateToPage(ws, Value)
End Sub

Sub Page_SignedOffSocialNetwork(Network As String, Extra As String)
	page.ws.Session.SetAttribute("authType", "")
	page.ws.Session.SetAttribute("authName", "")
	page.ws.Session.SetAttribute("IsAuthorized", "")			
	ABMShared.NavigateToPage(page.ws, "../")
End Sub

Sub Page_Ready()
	Log("ready!")
	page.RestoreNavigationBarPosition
End Sub

Sub LoadIcons() As List
	Dim Icons As List
	Icons.Initialize
	Icons.Add("mdi-action-3d-rotation")
	Icons.Add("mdi-action-accessibility")
	Icons.Add("mdi-action-account-balance")
	Icons.Add("mdi-action-account-balance-wallet")
	Icons.Add("mdi-action-account-box")
	Icons.Add("mdi-action-account-child")
	Icons.Add("mdi-action-account-circle")
	Icons.Add("mdi-action-add-shopping-cart")
	Icons.Add("mdi-action-alarm")
	Icons.Add("mdi-action-alarm-add")
	Icons.Add("mdi-action-alarm-off")
	Icons.Add("mdi-action-alarm-on")
	Icons.Add("mdi-action-android")
	Icons.Add("mdi-action-announcement")
	Icons.Add("mdi-action-aspect-ratio")
	Icons.Add("mdi-action-assessment")
	Icons.Add("mdi-action-assignment")
	Icons.Add("mdi-action-assignment-ind")
	Icons.Add("mdi-action-assignment-late")
	Icons.Add("mdi-action-assignment-return")
	Icons.Add("mdi-action-assignment-returned")
	Icons.Add("mdi-action-assignment-turned-in")
	Icons.Add("mdi-action-autorenew")
	Icons.Add("mdi-action-backup")
	Icons.Add("mdi-action-book")
	Icons.Add("mdi-action-bookmark")
	Icons.Add("mdi-action-bookmark-outline")
	Icons.Add("mdi-action-bug-report")
	Icons.Add("mdi-action-cached")
	Icons.Add("mdi-action-class")
	Icons.Add("mdi-action-credit-card")
	Icons.Add("mdi-action-dashboard")
	Icons.Add("mdi-action-delete")
	Icons.Add("mdi-action-description")
	Icons.Add("mdi-action-dns")
	Icons.Add("mdi-action-done")
	Icons.Add("mdi-action-done-all")
	Icons.Add("mdi-action-event")
	Icons.Add("mdi-action-exit-to-app")
	Icons.Add("mdi-action-explore")
	Icons.Add("mdi-action-extension")
	Icons.Add("mdi-action-face-unlock")
	Icons.Add("mdi-action-favorite")
	Icons.Add("mdi-action-favorite-outline")
	Icons.Add("mdi-action-find-in-page")
	Icons.Add("mdi-action-find-replace")
	Icons.Add("mdi-action-flip-to-back")
	Icons.Add("mdi-action-flip-to-front")
	Icons.Add("mdi-action-get-app")
	Icons.Add("mdi-action-grade")
	Icons.Add("mdi-action-group-work")
	Icons.Add("mdi-action-help")
	Icons.Add("mdi-action-highlight-remove")
	Icons.Add("mdi-action-history")
	Icons.Add("mdi-action-home")
	Icons.Add("mdi-action-https")
	Icons.Add("mdi-action-info")
	Icons.Add("mdi-action-info-outline")
	Icons.Add("mdi-action-input")
	Icons.Add("mdi-action-invert-colors")
	Icons.Add("mdi-action-label")
	Icons.Add("mdi-action-label-outline")
	Icons.Add("mdi-action-language")
	Icons.Add("mdi-action-launch")
	Icons.Add("mdi-action-list")
	Icons.Add("mdi-action-lock")
	Icons.Add("mdi-action-lock-open")
	Icons.Add("mdi-action-lock-outline")
	Icons.Add("mdi-action-loyalty")
	Icons.Add("mdi-action-markunread-mailbox")
	Icons.Add("mdi-action-note-add")
	Icons.Add("mdi-action-open-in-browser")
	Icons.Add("mdi-action-open-in-new")
	Icons.Add("mdi-action-open-with")
	Icons.Add("mdi-action-pageview")
	Icons.Add("mdi-action-payment")
	Icons.Add("mdi-action-perm-camera-mic")
	Icons.Add("mdi-action-perm-contact-cal")
	Icons.Add("mdi-action-perm-data-setting")
	Icons.Add("mdi-action-perm-device-info")
	Icons.Add("mdi-action-perm-identity")
	Icons.Add("mdi-action-perm-media")
	Icons.Add("mdi-action-perm-phone-msg")
	Icons.Add("mdi-action-perm-scan-wifi")
	Icons.Add("mdi-action-picture-in-picture")
	Icons.Add("mdi-action-polymer")
	Icons.Add("mdi-action-print")
	Icons.Add("mdi-action-query-builder")
	Icons.Add("mdi-action-question-answer")
	Icons.Add("mdi-action-receipt")
	Icons.Add("mdi-action-redeem")
	Icons.Add("mdi-action-report-problem")
	Icons.Add("mdi-action-restore")
	Icons.Add("mdi-action-room")
	Icons.Add("mdi-action-schedule")
	Icons.Add("mdi-action-search")
	Icons.Add("mdi-action-settings")
	Icons.Add("mdi-action-settings-applications")
	Icons.Add("mdi-action-settings-backup-restore")
	Icons.Add("mdi-action-settings-bluetooth")
	Icons.Add("mdi-action-settings-cell")
	Icons.Add("mdi-action-settings-display")
	Icons.Add("mdi-action-settings-ethernet")
	Icons.Add("mdi-action-settings-input-antenna")
	Icons.Add("mdi-action-settings-input-component")
	Icons.Add("mdi-action-settings-input-composite")
	Icons.Add("mdi-action-settings-input-hdmi")
	Icons.Add("mdi-action-settings-input-svideo")
	Icons.Add("mdi-action-settings-overscan")
	Icons.Add("mdi-action-settings-phone")
	Icons.Add("mdi-action-settings-power")
	Icons.Add("mdi-action-settings-remote")
	Icons.Add("mdi-action-settings-voice")
	Icons.Add("mdi-action-shop")
	Icons.Add("mdi-action-shop-two")
	Icons.Add("mdi-action-shopping-basket")
	Icons.Add("mdi-action-shopping-cart")
	Icons.Add("mdi-action-speaker-notes")
	Icons.Add("mdi-action-spellcheck")
	Icons.Add("mdi-action-star-rate")
	Icons.Add("mdi-action-stars")
	Icons.Add("mdi-action-store")
	Icons.Add("mdi-action-subject")
	Icons.Add("mdi-action-swap-horiz")
	Icons.Add("mdi-action-swap-vert")
	Icons.Add("mdi-action-swap-vert-circle")
	Icons.Add("mdi-action-system-update-tv")
	Icons.Add("mdi-action-tab")
	Icons.Add("mdi-action-tab-unselected")
	Icons.Add("mdi-action-theaters")
	Icons.Add("mdi-action-thumb-down")
	Icons.Add("mdi-action-thumb-up")
	Icons.Add("mdi-action-thumbs-up-down")
	Icons.Add("mdi-action-toc")
	Icons.Add("mdi-action-today")
	Icons.Add("mdi-action-track-changes")
	Icons.Add("mdi-action-translate")
	Icons.Add("mdi-action-trending-down")
	Icons.Add("mdi-action-trending-neutral")
	Icons.Add("mdi-action-trending-up")
	Icons.Add("mdi-action-turned-in")
	Icons.Add("mdi-action-turned-in-not")
	Icons.Add("mdi-action-verified-user")
	Icons.Add("mdi-action-view-agenda")
	Icons.Add("mdi-action-view-array")
	Icons.Add("mdi-action-view-carousel")
	Icons.Add("mdi-action-view-column")
	Icons.Add("mdi-action-view-day")
	Icons.Add("mdi-action-view-headline")
	Icons.Add("mdi-action-view-list")
	Icons.Add("mdi-action-view-module")
	Icons.Add("mdi-action-view-quilt")
	Icons.Add("mdi-action-view-stream")
	Icons.Add("mdi-action-view-week")
	Icons.Add("mdi-action-visibility")
	Icons.Add("mdi-action-visibility-off")
	Icons.Add("mdi-action-wallet-giftcard")
	Icons.Add("mdi-action-wallet-membership")
	Icons.Add("mdi-action-wallet-travel")
	Icons.Add("mdi-action-work")
	Icons.Add("mdi-av-album")
	Icons.Add("mdi-av-timer")
	Icons.Add("mdi-av-closed-caption")
	Icons.Add("mdi-av-equalizer")
	Icons.Add("mdi-av-explicit")
	Icons.Add("mdi-av-fast-forward")
	Icons.Add("mdi-av-fast-rewind")
	Icons.Add("mdi-av-games")
	Icons.Add("mdi-av-hearing")
	Icons.Add("mdi-av-high-quality")
	Icons.Add("mdi-av-loop")
	Icons.Add("mdi-av-mic")
	Icons.Add("mdi-av-mic-none")
	Icons.Add("mdi-av-mic-off")
	Icons.Add("mdi-av-movie")
	Icons.Add("mdi-av-my-library-add")
	Icons.Add("mdi-av-my-library-books")
	Icons.Add("mdi-av-my-library-music")
	Icons.Add("mdi-av-new-releases")
	Icons.Add("mdi-av-not-interested")
	Icons.Add("mdi-av-pause")
	Icons.Add("mdi-av-pause-circle-fill")
	Icons.Add("mdi-av-pause-circle-outline")
	Icons.Add("mdi-av-play-arrow")
	Icons.Add("mdi-av-play-circle-fill")
	Icons.Add("mdi-av-play-circle-outline")
	Icons.Add("mdi-av-play-shopping-bag")
	Icons.Add("mdi-av-playlist-add")
	Icons.Add("mdi-av-queue")
	Icons.Add("mdi-av-queue-music")
	Icons.Add("mdi-av-radio")
	Icons.Add("mdi-av-recent-actors")
	Icons.Add("mdi-av-repeat")
	Icons.Add("mdi-av-repeat-one")
	Icons.Add("mdi-av-replay")
	Icons.Add("mdi-av-shuffle")
	Icons.Add("mdi-av-skip-next")
	Icons.Add("mdi-av-skip-previous")
	Icons.Add("mdi-av-snooze")
	Icons.Add("mdi-av-stop")
	Icons.Add("mdi-av-subtitles")
	Icons.Add("mdi-av-surround-sound")
	Icons.Add("mdi-av-video-collection")
	Icons.Add("mdi-av-videocam")
	Icons.Add("mdi-av-videocam-off")
	Icons.Add("mdi-av-volume-down")
	Icons.Add("mdi-av-volume-mute")
	Icons.Add("mdi-av-volume-off")
	Icons.Add("mdi-av-volume-up")
	Icons.Add("mdi-av-web")
	Icons.Add("mdi-communication-business")
	Icons.Add("mdi-communication-call")
	Icons.Add("mdi-communication-call-end")
	Icons.Add("mdi-communication-call-made")
	Icons.Add("mdi-communication-call-merge")
	Icons.Add("mdi-communication-call-missed")
	Icons.Add("mdi-communication-call-received")
	Icons.Add("mdi-communication-call-split")
	Icons.Add("mdi-communication-chat")
	Icons.Add("mdi-communication-clear-all")
	Icons.Add("mdi-communication-comment")
	Icons.Add("mdi-communication-contacts")
	Icons.Add("mdi-communication-dialer-sip")
	Icons.Add("mdi-communication-dialpad")
	Icons.Add("mdi-communication-dnd-on")
	Icons.Add("mdi-communication-email")
	Icons.Add("mdi-communication-forum")
	Icons.Add("mdi-communication-import-export")
	Icons.Add("mdi-communication-invert-colors-off")
	Icons.Add("mdi-communication-invert-colors-on")
	Icons.Add("mdi-communication-live-help")
	Icons.Add("mdi-communication-location-off")
	Icons.Add("mdi-communication-location-on")
	Icons.Add("mdi-communication-message")
	Icons.Add("mdi-communication-messenger")
	Icons.Add("mdi-communication-no-sim")
	Icons.Add("mdi-communication-phone")
	Icons.Add("mdi-communication-portable-wifi-off")
	Icons.Add("mdi-communication-quick-contacts-dialer")
	Icons.Add("mdi-communication-quick-contacts-mail")
	Icons.Add("mdi-communication-ring-volume")
	Icons.Add("mdi-communication-stay-current-landscape")
	Icons.Add("mdi-communication-stay-current-portrait")
	Icons.Add("mdi-communication-stay-primary-landscape")
	Icons.Add("mdi-communication-stay-primary-portrait")
	Icons.Add("mdi-communication-swap-calls")
	Icons.Add("mdi-communication-textsms")
	Icons.Add("mdi-communication-voicemail")
	Icons.Add("mdi-communication-vpn-key")
	Icons.Add("mdi-content-add")
	Icons.Add("mdi-content-add-box")
	Icons.Add("mdi-content-add-circle")
	Icons.Add("mdi-content-add-circle-outline")
	Icons.Add("mdi-content-archive")
	Icons.Add("mdi-content-backspace")
	Icons.Add("mdi-content-block")
	Icons.Add("mdi-content-clear")
	Icons.Add("mdi-content-content-copy")
	Icons.Add("mdi-content-content-cut")
	Icons.Add("mdi-content-content-paste")
	Icons.Add("mdi-content-create")
	Icons.Add("mdi-content-drafts")
	Icons.Add("mdi-content-filter-list")
	Icons.Add("mdi-content-flag")
	Icons.Add("mdi-content-forward")
	Icons.Add("mdi-content-gesture")
	Icons.Add("mdi-content-inbox")
	Icons.Add("mdi-content-link")
	Icons.Add("mdi-content-mail")
	Icons.Add("mdi-content-markunread")
	Icons.Add("mdi-content-redo")
	Icons.Add("mdi-content-remove")
	Icons.Add("mdi-content-remove-circle")
	Icons.Add("mdi-content-remove-circle-outline")
	Icons.Add("mdi-content-reply")
	Icons.Add("mdi-content-reply-all")
	Icons.Add("mdi-content-report")
	Icons.Add("mdi-content-save")
	Icons.Add("mdi-content-select-all")
	Icons.Add("mdi-content-send")
	Icons.Add("mdi-content-sort")
	Icons.Add("mdi-content-text-format")
	Icons.Add("mdi-content-undo")
	Icons.Add("mdi-device-access-alarm")
	Icons.Add("mdi-device-access-alarms")
	Icons.Add("mdi-device-access-time")
	Icons.Add("mdi-device-add-alarm")
	Icons.Add("mdi-device-airplanemode-off")
	Icons.Add("mdi-device-airplanemode-on")
	Icons.Add("mdi-device-battery-20")
	Icons.Add("mdi-device-battery-30")
	Icons.Add("mdi-device-battery-50")
	Icons.Add("mdi-device-battery-60")
	Icons.Add("mdi-device-battery-80")
	Icons.Add("mdi-device-battery-90")
	Icons.Add("mdi-device-battery-alert")
	Icons.Add("mdi-device-battery-charging-20")
	Icons.Add("mdi-device-battery-charging-30")
	Icons.Add("mdi-device-battery-charging-50")
	Icons.Add("mdi-device-battery-charging-60")
	Icons.Add("mdi-device-battery-charging-80")
	Icons.Add("mdi-device-battery-charging-90")
	Icons.Add("mdi-device-battery-charging-full")
	Icons.Add("mdi-device-battery-full")
	Icons.Add("mdi-device-battery-std")
	Icons.Add("mdi-device-battery-unknown")
	Icons.Add("mdi-device-bluetooth")
	Icons.Add("mdi-device-bluetooth-connected")
	Icons.Add("mdi-device-bluetooth-disabled")
	Icons.Add("mdi-device-bluetooth-searching")
	Icons.Add("mdi-device-brightness-auto")
	Icons.Add("mdi-device-brightness-high")
	Icons.Add("mdi-device-brightness-low")
	Icons.Add("mdi-device-brightness-medium")
	Icons.Add("mdi-device-data-usage")
	Icons.Add("mdi-device-developer-mode")
	Icons.Add("mdi-device-devices")
	Icons.Add("mdi-device-dvr")
	Icons.Add("mdi-device-gps-fixed")
	Icons.Add("mdi-device-gps-not-fixed")
	Icons.Add("mdi-device-gps-off")
	Icons.Add("mdi-device-location-disabled")
	Icons.Add("mdi-device-location-searching")
	Icons.Add("mdi-device-multitrack-audio")
	Icons.Add("mdi-device-network-cell")
	Icons.Add("mdi-device-network-wifi")
	Icons.Add("mdi-device-nfc")
	Icons.Add("mdi-device-now-wallpaper")
	Icons.Add("mdi-device-now-widgets")
	Icons.Add("mdi-device-screen-lock-landscape")
	Icons.Add("mdi-device-screen-lock-portrait")
	Icons.Add("mdi-device-screen-lock-rotation")
	Icons.Add("mdi-device-screen-rotation")
	Icons.Add("mdi-device-sd-storage")
	Icons.Add("mdi-device-settings-system-daydream")
	Icons.Add("mdi-device-signal-cellular-0-bar")
	Icons.Add("mdi-device-signal-cellular-1-bar")
	Icons.Add("mdi-device-signal-cellular-2-bar")
	Icons.Add("mdi-device-signal-cellular-3-bar")
	Icons.Add("mdi-device-signal-cellular-4-bar")
	Icons.Add("mdi-device-signal-cellular-connected-no-internet-0-bar")
	Icons.Add("mdi-device-signal-cellular-connected-no-internet-1-bar")
	Icons.Add("mdi-device-signal-cellular-connected-no-internet-2-bar")
	Icons.Add("mdi-device-signal-cellular-connected-no-internet-3-bar")
	Icons.Add("mdi-device-signal-cellular-connected-no-internet-4-bar")
	Icons.Add("mdi-device-signal-cellular-no-sim")
	Icons.Add("mdi-device-signal-cellular-null")
	Icons.Add("mdi-device-signal-cellular-off")
	Icons.Add("mdi-device-signal-wifi-0-bar")
	Icons.Add("mdi-device-signal-wifi-1-bar")
	Icons.Add("mdi-device-signal-wifi-2-bar")
	Icons.Add("mdi-device-signal-wifi-3-bar")
	Icons.Add("mdi-device-signal-wifi-4-bar")
	Icons.Add("mdi-device-signal-wifi-off")
	Icons.Add("mdi-device-storage")
	Icons.Add("mdi-device-usb")
	Icons.Add("mdi-device-wifi-lock")
	Icons.Add("mdi-device-wifi-tethering")
	Icons.Add("mdi-editor-attach-file")
	Icons.Add("mdi-editor-attach-money")
	Icons.Add("mdi-editor-border-all")
	Icons.Add("mdi-editor-border-bottom")
	Icons.Add("mdi-editor-border-clear")
	Icons.Add("mdi-editor-border-color")
	Icons.Add("mdi-editor-border-horizontal")
	Icons.Add("mdi-editor-border-inner")
	Icons.Add("mdi-editor-border-left")
	Icons.Add("mdi-editor-border-outer")
	Icons.Add("mdi-editor-border-right")
	Icons.Add("mdi-editor-border-style")
	Icons.Add("mdi-editor-border-top")
	Icons.Add("mdi-editor-border-vertical")
	Icons.Add("mdi-editor-format-align-center")
	Icons.Add("mdi-editor-format-align-justify")
	Icons.Add("mdi-editor-format-align-left")
	Icons.Add("mdi-editor-format-align-right")
	Icons.Add("mdi-editor-format-bold")
	Icons.Add("mdi-editor-format-clear")
	Icons.Add("mdi-editor-format-color-fill")
	Icons.Add("mdi-editor-format-color-reset")
	Icons.Add("mdi-editor-format-color-text")
	Icons.Add("mdi-editor-format-indent-decrease")
	Icons.Add("mdi-editor-format-indent-increase")
	Icons.Add("mdi-editor-format-italic")
	Icons.Add("mdi-editor-format-line-spacing")
	Icons.Add("mdi-editor-format-list-bulleted")
	Icons.Add("mdi-editor-format-list-numbered")
	Icons.Add("mdi-editor-format-paint")
	Icons.Add("mdi-editor-format-quote")
	Icons.Add("mdi-editor-format-size")
	Icons.Add("mdi-editor-format-strikethrough")
	Icons.Add("mdi-editor-format-textdirection-l-to-r")
	Icons.Add("mdi-editor-format-textdirection-r-to-l")
	Icons.Add("mdi-editor-format-underline")
	Icons.Add("mdi-editor-functions")
	Icons.Add("mdi-editor-insert-chart")
	Icons.Add("mdi-editor-insert-comment")
	Icons.Add("mdi-editor-insert-drive-file")
	Icons.Add("mdi-editor-insert-emoticon")
	Icons.Add("mdi-editor-insert-invitation")
	Icons.Add("mdi-editor-insert-link")
	Icons.Add("mdi-editor-insert-photo")
	Icons.Add("mdi-editor-merge-type")
	Icons.Add("mdi-editor-mode-comment")
	Icons.Add("mdi-editor-mode-edit")
	Icons.Add("mdi-editor-publish")
	Icons.Add("mdi-editor-vertical-align-bottom")
	Icons.Add("mdi-editor-vertical-align-center")
	Icons.Add("mdi-editor-vertical-align-top")
	Icons.Add("mdi-editor-wrap-text")
	Icons.Add("mdi-file-attachment")
	Icons.Add("mdi-file-cloud")
	Icons.Add("mdi-file-cloud-circle")
	Icons.Add("mdi-file-cloud-done")
	Icons.Add("mdi-file-cloud-download")
	Icons.Add("mdi-file-cloud-off")
	Icons.Add("mdi-file-cloud-queue")
	Icons.Add("mdi-file-cloud-upload")
	Icons.Add("mdi-file-file-download")
	Icons.Add("mdi-file-file-upload")
	Icons.Add("mdi-file-folder")
	Icons.Add("mdi-file-folder-open")
	Icons.Add("mdi-file-folder-shared")
	Icons.Add("mdi-hardware-cast")
	Icons.Add("mdi-hardware-cast-connected")
	Icons.Add("mdi-hardware-computer")
	Icons.Add("mdi-hardware-desktop-mac")
	Icons.Add("mdi-hardware-desktop-windows")
	Icons.Add("mdi-hardware-dock")
	Icons.Add("mdi-hardware-gamepad")
	Icons.Add("mdi-hardware-headset")
	Icons.Add("mdi-hardware-headset-mic")
	Icons.Add("mdi-hardware-keyboard")
	Icons.Add("mdi-hardware-keyboard-alt")
	Icons.Add("mdi-hardware-keyboard-arrow-down")
	Icons.Add("mdi-hardware-keyboard-arrow-left")
	Icons.Add("mdi-hardware-keyboard-arrow-right")
	Icons.Add("mdi-hardware-keyboard-arrow-up")
	Icons.Add("mdi-hardware-keyboard-backspace")
	Icons.Add("mdi-hardware-keyboard-capslock")
	Icons.Add("mdi-hardware-keyboard-control")
	Icons.Add("mdi-hardware-keyboard-hide")
	Icons.Add("mdi-hardware-keyboard-return")
	Icons.Add("mdi-hardware-keyboard-tab")
	Icons.Add("mdi-hardware-keyboard-voice")
	Icons.Add("mdi-hardware-laptop")
	Icons.Add("mdi-hardware-laptop-chromebook")
	Icons.Add("mdi-hardware-laptop-mac")
	Icons.Add("mdi-hardware-laptop-windows")
	Icons.Add("mdi-hardware-memory")
	Icons.Add("mdi-hardware-mouse")
	Icons.Add("mdi-hardware-phone-android")
	Icons.Add("mdi-hardware-phone-iphone")
	Icons.Add("mdi-hardware-phonelink")
	Icons.Add("mdi-hardware-phonelink-off")
	Icons.Add("mdi-hardware-security")
	Icons.Add("mdi-hardware-sim-card")
	Icons.Add("mdi-hardware-smartphone")
	Icons.Add("mdi-hardware-speaker")
	Icons.Add("mdi-hardware-tablet")
	Icons.Add("mdi-hardware-tablet-android")
	Icons.Add("mdi-hardware-tablet-mac")
	Icons.Add("mdi-hardware-tv")
	Icons.Add("mdi-hardware-watch")
	Icons.Add("mdi-image-add-to-photos")
	Icons.Add("mdi-image-adjust")
	Icons.Add("mdi-image-assistant-photo")
	Icons.Add("mdi-image-audiotrack")
	Icons.Add("mdi-image-blur-circular")
	Icons.Add("mdi-image-blur-linear")
	Icons.Add("mdi-image-blur-off")
	Icons.Add("mdi-image-blur-on")
	Icons.Add("mdi-image-brightness-1")
	Icons.Add("mdi-image-brightness-2")
	Icons.Add("mdi-image-brightness-3")
	Icons.Add("mdi-image-brightness-4")
	Icons.Add("mdi-image-brightness-5")
	Icons.Add("mdi-image-brightness-6")
	Icons.Add("mdi-image-brightness-7")
	Icons.Add("mdi-image-brush")
	Icons.Add("mdi-image-camera")
	Icons.Add("mdi-image-camera-alt")
	Icons.Add("mdi-image-camera-front")
	Icons.Add("mdi-image-camera-rear")
	Icons.Add("mdi-image-camera-roll")
	Icons.Add("mdi-image-center-focus-strong")
	Icons.Add("mdi-image-center-focus-weak")
	Icons.Add("mdi-image-collections")
	Icons.Add("mdi-image-color-lens")
	Icons.Add("mdi-image-colorize")
	Icons.Add("mdi-image-compare")
	Icons.Add("mdi-image-control-point")
	Icons.Add("mdi-image-control-point-duplicate")
	Icons.Add("mdi-image-crop-16-9")
	Icons.Add("mdi-image-crop")
	Icons.Add("mdi-image-crop-3-2")
	Icons.Add("mdi-image-crop-5-4")
	Icons.Add("mdi-image-crop-7-5")
	Icons.Add("mdi-image-crop-din")
	Icons.Add("mdi-image-crop-free")
	Icons.Add("mdi-image-crop-landscape")
	Icons.Add("mdi-image-crop-original")
	Icons.Add("mdi-image-crop-portrait")
	Icons.Add("mdi-image-crop-square")
	Icons.Add("mdi-image-dehaze")
	Icons.Add("mdi-image-details")
	Icons.Add("mdi-image-edit")
	Icons.Add("mdi-image-exposure")
	Icons.Add("mdi-image-exposure-minus-1")
	Icons.Add("mdi-image-exposure-minus-2")
	Icons.Add("mdi-image-exposure-plus-1")
	Icons.Add("mdi-image-exposure-plus-2")
	Icons.Add("mdi-image-exposure-zero")
	Icons.Add("mdi-image-filter-1")
	Icons.Add("mdi-image-filter")
	Icons.Add("mdi-image-filter-2")
	Icons.Add("mdi-image-filter-3")
	Icons.Add("mdi-image-filter-4")
	Icons.Add("mdi-image-filter-5")
	Icons.Add("mdi-image-filter-6")
	Icons.Add("mdi-image-filter-7")
	Icons.Add("mdi-image-filter-8")
	Icons.Add("mdi-image-filter-9")
	Icons.Add("mdi-image-filter-9-plus")
	Icons.Add("mdi-image-filter-b-and-w")
	Icons.Add("mdi-image-filter-center-focus")
	Icons.Add("mdi-image-filter-drama")
	Icons.Add("mdi-image-filter-frames")
	Icons.Add("mdi-image-filter-hdr")
	Icons.Add("mdi-image-filter-none")
	Icons.Add("mdi-image-filter-tilt-shift")
	Icons.Add("mdi-image-filter-vintage")
	Icons.Add("mdi-image-flare")
	Icons.Add("mdi-image-flash-auto")
	Icons.Add("mdi-image-flash-off")
	Icons.Add("mdi-image-flash-on")
	Icons.Add("mdi-image-flip")
	Icons.Add("mdi-image-gradient")
	Icons.Add("mdi-image-grain")
	Icons.Add("mdi-image-grid-off")
	Icons.Add("mdi-image-grid-on")
	Icons.Add("mdi-image-hdr-off")
	Icons.Add("mdi-image-hdr-on")
	Icons.Add("mdi-image-hdr-strong")
	Icons.Add("mdi-image-hdr-weak")
	Icons.Add("mdi-image-healing")
	Icons.Add("mdi-image-image")
	Icons.Add("mdi-image-image-aspect-ratio")
	Icons.Add("mdi-image-iso")
	Icons.Add("mdi-image-landscape")
	Icons.Add("mdi-image-leak-add")
	Icons.Add("mdi-image-leak-remove")
	Icons.Add("mdi-image-lens")
	Icons.Add("mdi-image-looks")
	Icons.Add("mdi-image-looks-3")
	Icons.Add("mdi-image-looks-4")
	Icons.Add("mdi-image-looks-5")
	Icons.Add("mdi-image-looks-6")
	Icons.Add("mdi-image-looks-one")
	Icons.Add("mdi-image-looks-two")
	Icons.Add("mdi-image-loupe")
	Icons.Add("mdi-image-movie-creation")
	Icons.Add("mdi-image-nature")
	Icons.Add("mdi-image-nature-people")
	Icons.Add("mdi-image-navigate-before")
	Icons.Add("mdi-image-navigate-next")
	Icons.Add("mdi-image-palette")
	Icons.Add("mdi-image-panorama")
	Icons.Add("mdi-image-panorama-fisheye")
	Icons.Add("mdi-image-panorama-horizontal")
	Icons.Add("mdi-image-panorama-vertical")
	Icons.Add("mdi-image-panorama-wide-angle")
	Icons.Add("mdi-image-photo")
	Icons.Add("mdi-image-photo-album")
	Icons.Add("mdi-image-photo-camera")
	Icons.Add("mdi-image-photo-library")
	Icons.Add("mdi-image-portrait")
	Icons.Add("mdi-image-remove-red-eye")
	Icons.Add("mdi-image-rotate-left")
	Icons.Add("mdi-image-rotate-right")
	Icons.Add("mdi-image-slideshow")
	Icons.Add("mdi-image-straighten")
	Icons.Add("mdi-image-style")
	Icons.Add("mdi-image-switch-camera")
	Icons.Add("mdi-image-switch-video")
	Icons.Add("mdi-image-tag-faces")
	Icons.Add("mdi-image-texture")
	Icons.Add("mdi-image-timelapse")
	Icons.Add("mdi-image-timer-10")
	Icons.Add("mdi-image-timer")
	Icons.Add("mdi-image-timer-3")
	Icons.Add("mdi-image-timer-auto")
	Icons.Add("mdi-image-timer-off")
	Icons.Add("mdi-image-tonality")
	Icons.Add("mdi-image-transform")
	Icons.Add("mdi-image-tune")
	Icons.Add("mdi-image-wb-auto")
	Icons.Add("mdi-image-wb-cloudy")
	Icons.Add("mdi-image-wb-incandescent")
	Icons.Add("mdi-image-wb-irradescent")
	Icons.Add("mdi-image-wb-sunny")
	Icons.Add("mdi-maps-beenhere")
	Icons.Add("mdi-maps-directions")
	Icons.Add("mdi-maps-directions-bike")
	Icons.Add("mdi-maps-directions-bus")
	Icons.Add("mdi-maps-directions-car")
	Icons.Add("mdi-maps-directions-ferry")
	Icons.Add("mdi-maps-directions-subway")
	Icons.Add("mdi-maps-directions-train")
	Icons.Add("mdi-maps-directions-transit")
	Icons.Add("mdi-maps-directions-walk")
	Icons.Add("mdi-maps-flight")
	Icons.Add("mdi-maps-hotel")
	Icons.Add("mdi-maps-layers")
	Icons.Add("mdi-maps-layers-clear")
	Icons.Add("mdi-maps-local-airport")
	Icons.Add("mdi-maps-local-atm")
	Icons.Add("mdi-maps-local-attraction")
	Icons.Add("mdi-maps-local-bar")
	Icons.Add("mdi-maps-local-cafe")
	Icons.Add("mdi-maps-local-car-wash")
	Icons.Add("mdi-maps-local-convenience-store")
	Icons.Add("mdi-maps-local-drink")
	Icons.Add("mdi-maps-local-florist")
	Icons.Add("mdi-maps-local-gas-station")
	Icons.Add("mdi-maps-local-grocery-store")
	Icons.Add("mdi-maps-local-hospital")
	Icons.Add("mdi-maps-local-hotel")
	Icons.Add("mdi-maps-local-laundry-service")
	Icons.Add("mdi-maps-local-library")
	Icons.Add("mdi-maps-local-mall")
	Icons.Add("mdi-maps-local-movies")
	Icons.Add("mdi-maps-local-offer")
	Icons.Add("mdi-maps-local-parking")
	Icons.Add("mdi-maps-local-pharmacy")
	Icons.Add("mdi-maps-local-phone")
	Icons.Add("mdi-maps-local-pizza")
	Icons.Add("mdi-maps-local-play")
	Icons.Add("mdi-maps-local-post-office")
	Icons.Add("mdi-maps-local-print-shop")
	Icons.Add("mdi-maps-local-restaurant")
	Icons.Add("mdi-maps-local-see")
	Icons.Add("mdi-maps-local-shipping")
	Icons.Add("mdi-maps-local-taxi")
	Icons.Add("mdi-maps-location-history")
	Icons.Add("mdi-maps-map")
	Icons.Add("mdi-maps-my-location")
	Icons.Add("mdi-maps-navigation")
	Icons.Add("mdi-maps-pin-drop")
	Icons.Add("mdi-maps-place")
	Icons.Add("mdi-maps-rate-review")
	Icons.Add("mdi-maps-restaurant-menu")
	Icons.Add("mdi-maps-satellite")
	Icons.Add("mdi-maps-store-mall-directory")
	Icons.Add("mdi-maps-terrain")
	Icons.Add("mdi-maps-traffic")
	Icons.Add("mdi-navigation-apps")
	Icons.Add("mdi-navigation-arrow-back")
	Icons.Add("mdi-navigation-arrow-drop-down")
	Icons.Add("mdi-navigation-arrow-drop-down-circle")
	Icons.Add("mdi-navigation-arrow-drop-up")
	Icons.Add("mdi-navigation-arrow-forward")
	Icons.Add("mdi-navigation-cancel")
	Icons.Add("mdi-navigation-check")
	Icons.Add("mdi-navigation-chevron-left")
	Icons.Add("mdi-navigation-chevron-right")
	Icons.Add("mdi-navigation-close")
	Icons.Add("mdi-navigation-expand-less")
	Icons.Add("mdi-navigation-expand-more")
	Icons.Add("mdi-navigation-fullscreen")
	Icons.Add("mdi-navigation-fullscreen-exit")
	Icons.Add("mdi-navigation-menu")
	Icons.Add("mdi-navigation-more-horiz")
	Icons.Add("mdi-navigation-more-vert")
	Icons.Add("mdi-navigation-refresh")
	Icons.Add("mdi-navigation-unfold-less")
	Icons.Add("mdi-navigation-unfold-more")
	Icons.Add("mdi-notification-adb")
	Icons.Add("mdi-notification-bluetooth-audio")
	Icons.Add("mdi-notification-disc-full")
	Icons.Add("mdi-notification-dnd-forwardslash")
	Icons.Add("mdi-notification-do-not-disturb")
	Icons.Add("mdi-notification-drive-eta")
	Icons.Add("mdi-notification-event-available")
	Icons.Add("mdi-notification-event-busy")
	Icons.Add("mdi-notification-event-note")
	Icons.Add("mdi-notification-folder-special")
	Icons.Add("mdi-notification-mms")
	Icons.Add("mdi-notification-more")
	Icons.Add("mdi-notification-network-locked")
	Icons.Add("mdi-notification-phone-bluetooth-speaker")
	Icons.Add("mdi-notification-phone-forwarded")
	Icons.Add("mdi-notification-phone-in-talk")
	Icons.Add("mdi-notification-phone-locked")
	Icons.Add("mdi-notification-phone-missed")
	Icons.Add("mdi-notification-phone-paused")
	Icons.Add("mdi-notification-play-download")
	Icons.Add("mdi-notification-play-install")
	Icons.Add("mdi-notification-sd-card")
	Icons.Add("mdi-notification-sim-card-alert")
	Icons.Add("mdi-notification-sms")
	Icons.Add("mdi-notification-sms-failed")
	Icons.Add("mdi-notification-sync")
	Icons.Add("mdi-notification-sync-disabled")
	Icons.Add("mdi-notification-sync-problem")
	Icons.Add("mdi-notification-system-update")
	Icons.Add("mdi-notification-tap-and-play")
	Icons.Add("mdi-notification-time-to-leave")
	Icons.Add("mdi-notification-vibration")
	Icons.Add("mdi-notification-voice-chat")
	Icons.Add("mdi-notification-vpn-lock")
	Icons.Add("mdi-social-cake")
	Icons.Add("mdi-social-domain")
	Icons.Add("mdi-social-group")
	Icons.Add("mdi-social-group-add")
	Icons.Add("mdi-social-location-city")
	Icons.Add("mdi-social-mood")
	Icons.Add("mdi-social-notifications")
	Icons.Add("mdi-social-notifications-none")
	Icons.Add("mdi-social-notifications-off")
	Icons.Add("mdi-social-notifications-on")
	Icons.Add("mdi-social-notifications-paused")
	Icons.Add("mdi-social-pages")
	Icons.Add("mdi-social-party-mode")
	Icons.Add("mdi-social-people")
	Icons.Add("mdi-social-people-outline")
	Icons.Add("mdi-social-person")
	Icons.Add("mdi-social-person-add")
	Icons.Add("mdi-social-person-outline")
	Icons.Add("mdi-social-plus-one")
	Icons.Add("mdi-social-poll")
	Icons.Add("mdi-social-public")
	Icons.Add("mdi-social-school")
	Icons.Add("mdi-social-share")
	Icons.Add("mdi-social-whatshot")
	Icons.Add("mdi-toggle-check-box")
	Icons.Add("mdi-toggle-check-box-outline-blank")
	Icons.Add("mdi-toggle-radio-button-off")
	Icons.Add("mdi-toggle-radio-button-on")
	Return Icons
End Sub

